/*
 *  dmachinemon / a distributed machine monitor by dancer.
 *  Copyright (C) 2001 Junichi Uekawa
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * libdmachinemon include file.
 */

#ifndef __DMACHINEMON_H
#define __DMACHINEMON_H

#ifdef __cplusplus
extern "C" {
#endif
  
#include <dmachinemon/dmachinemon-libdatabase.h>
#include <dmachinemon/dmachinemon-commandlineparser.h>
#include <dmachinemon/dmachinemon-libnodeinfo.h>
#include <dmachinemon/libsocket.h>
#include <dmachinemon/dmachinemon-servent-libroute.h>
#include <dmachinemon/dmachinemon-libp2papplication.h>
#include <dmachinemon/dmachinemon-daemonize.h>
#include <dmachinemon/dnas-connect-to-host.h>

#ifdef __cplusplus
}
#endif


#endif
